@@ -1,7 +1,7 @@
 /*
  *  IHU -- I Hear U, easy VoIP application using Speex and Qt
  *
- *  Copyright (C) 2003-2005 M. Trotta - <mrotta@users.sourceforge.net>
+ *  Copyright (C) 2003-2006 Matteo Trotta - <mrotta@users.sourceforge.net>
  *
  *  http://ihu.sourceforge.net
  *
@@ -21,16 +21,18 @@
  */
 
 /*
- *  This code uses one of the Blowfish algorithm available 
+ *  This code uses one of the Blowfish algorithm available
  *  at Bruce Schneider web site: http://www.schneier.com/
  *  Author: Unknown
+ *
+ *  The code has been adapted for IHU by Matteo Trotta
 */
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
-#include "Blowfish.hpp"
-#include "Error.hpp"
+#include "Error.h"
+#include "Blowfish.h"
 
 #define F(x)    (((SB[0][x.byte.zero] + SB[1][x.byte.one]) ^ SB[2][x.byte.two]) + SB[3][x.byte.three])
 
