@@ -1,7 +1,7 @@
 /*
  *  IHU -- I Hear U, easy VoIP application using Speex and Qt
  *
- *  Copyright (C) 2003-2005 M. Trotta - <mrotta@users.sourceforge.net>
+ *  Copyright (C) 2003-2006 Matteo Trotta - <mrotta@users.sourceforge.net>
  *
  *  http://ihu.sourceforge.net
  *
@@ -20,7 +20,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
  */
 
-#include "Error.hpp"
+#include "Error.h"
 
 Error::Error(QString s)
 	: text(s)
