@@ -1,7 +1,7 @@
 /*
  *  IHU -- I Hear U, easy VoIP application using Speex and Qt
  *
- *  Copyright (C) 2003-2005 M. Trotta - <mrotta@users.sourceforge.net>
+ *  Copyright (C) 2003-2006 Matteo Trotta - <mrotta@users.sourceforge.net>
  *
  *  http://ihu.sourceforge.net
  *
@@ -44,16 +44,18 @@
 #include <qcombobox.h>
 #include <qlistbox.h>
 
+#include "Error.h"
 #include "Ihu.hpp"
 #include "Settings.hpp"
 #include "LogViewer.hpp"
-#include "Error.hpp"
 
 // Timeout (ms) for statistics
 #define STAT_TIME 1000
 #define RESTART_TIME 3000
 #define MAX_COUNT 10
 
+#define VDATE "2006/Oct/23"
+
 /*
  *  Constructs a Ihu as a child of 'parent', with the
  *  name 'name' and widget flags set to 'f'.
@@ -252,6 +254,8 @@ Ihu::Ihu( QWidget* parent, const char* name, WFlags fl )
 	settingsAction->setIconSet( QIconSet( QPixmap::fromMimeSource( "configure.png" ) ) );
 	filePlayFileAction = new QAction( this, "filePlayFileAction" );
 	filePlayFileAction->setIconSet( QIconSet( QPixmap::fromMimeSource( "open.png" ) ) );
+	fileConvertFileAction = new QAction( this, "fileConvertFileAction" );
+	fileConvertFileAction->setIconSet( QIconSet( QPixmap::fromMimeSource( "open.png" ) ) );
 	cryptAction = new QAction( this, "cryptAction" );
 	cryptAction->setToggleAction(TRUE);
 	changeKeyAction = new QAction( this, "changeKeyAction" );
@@ -268,6 +272,7 @@ Ihu::Ihu( QWidget* parent, const char* name, WFlags fl )
 	fileMenu = new QPopupMenu( this );
 	
 	filePlayFileAction->addTo( fileMenu );
+	fileConvertFileAction->addTo( fileMenu );
 	fileMenu->insertSeparator();
 	fileQuitAction->addTo( fileMenu );
 	menubar->insertItem( "", fileMenu, 0 );
@@ -325,6 +330,7 @@ Ihu::Ihu( QWidget* parent, const char* name, WFlags fl )
 	connect( thSlider, SIGNAL( sliderPressed() ), this, SLOT( sliderPress() ) );
 	connect( thSlider, SIGNAL( sliderReleased() ), this, SLOT( sliderRelease() ) );
 	connect( filePlayFileAction, SIGNAL( activated() ), this, SLOT( play() ) );
+	connect( fileConvertFileAction, SIGNAL( activated() ), this, SLOT( convert() ) );
 	connect( muteMicButton, SIGNAL( toggled(bool) ), this, SLOT( transmitterStatus(bool) ) );
 	connect( muteSpkButton, SIGNAL( toggled(bool) ), this, SLOT( receiverStatus(bool) ) );
 	connect( hostEdit->lineEdit(), SIGNAL( returnPressed() ), this, SLOT( startAll() ) );
@@ -376,6 +382,9 @@ void Ihu::languageChange()
 	filePlayFileAction->setText( tr( "Play File"  ) );
 	filePlayFileAction->setMenuText( tr( "&Play file..." ) );
 	filePlayFileAction->setStatusTip( tr( "Play IHU File" ) );
+	fileConvertFileAction->setText( tr( "Convert .ihu file to .spx"  ) );
+	fileConvertFileAction->setMenuText( tr( "&Convert .ihu file to .spx..." ) );
+	fileConvertFileAction->setStatusTip( tr( "Converts .ihu files to standard Ogg speex" ) );
 	settingsAction->setText( tr( "Settings" ) );
 	settingsAction->setMenuText( tr( "&Settings..." ) );
 	settingsAction->setStatusTip( tr( "Adjust settings" ) );
@@ -401,6 +410,7 @@ void Ihu::languageChange()
 	fileQuitAction->setAccel( QKeySequence( tr( "Ctrl+Q" ) ) );
 	settingsAction->setAccel( QKeySequence( tr( "Ctrl+S" ) ) );
 	filePlayFileAction->setAccel( QKeySequence( tr( "Ctrl+F" ) ) );
+	fileConvertFileAction->setAccel( QKeySequence( tr( "Ctrl+T" ) ) );
 	adrAction->setAccel( QKeySequence( tr( "Ctrl+R" ) ) );
 	agcAction->setAccel( QKeySequence( tr( "Ctrl+G" ) ) );
 	setDecKeyAction->setAccel( QKeySequence( tr( "Ctrl+D" ) ) );
@@ -435,6 +445,7 @@ void Ihu::initIhu(bool file)
 	try
 	{
 		fromFile = file;
+		ihu2spx = false;
 		sliderFree = true;
 		listening = false;
 		received = false;
@@ -477,7 +488,7 @@ void Ihu::initIhu(bool file)
 	catch (Error e)
 	{
 		showMessageCritical(e.getText());
-		qWarning("Program abort due to a critical error:" + e.getText());
+		qWarning("Program abort due to a critical error: " + e.getText());
 		exit(1);
 	}
 	
@@ -496,9 +507,8 @@ void Ihu::applySettings()
 	int srate, quality, vbr, abr, complexity, vad, dtx, txstop;
 	float vbrquality;
 
-	transmitter->dump(config.readEntry("/ihu/general/name"), config.readEntry("/ihu/general/dumpout"));
-	receiver->dump(config.readEntry("/ihu/general/dumpin"));
-	
+	transmitter->setName(config.readEntry("/ihu/general/name"));
+
 	if (config.readBoolEntry("/ihu/general/tray"))
 	{
 		if (trayIcon == NULL)
@@ -567,7 +577,8 @@ void Ihu::applySettings()
 	transmitter->setup(srate, quality, abr, vbr, vbrquality, complexity, vad, dtx, txstop);
 
 	recorder->setup(config.readNumEntry("/ihu/sound/inputdriver"), config.readEntry("/ihu/sound/inputinterface"));
-	player->setup(config.readNumEntry("/ihu/sound/outputdriver"), config.readEntry("/ihu/sound/outputinterface"), config.readNumEntry("/ihu/sound/ringvolume"));
+	player->setup(config.readNumEntry("/ihu/sound/outputdriver"), config.readEntry("/ihu/sound/outputinterface"), 
+			config.readNumEntry("/ihu/sound/ringvolume"), config.readNumEntry("/ihu/sound/prepackets"));
 	
 	if (fromFile || config.readNumEntry("/ihu/sound/outputdriver"))
 		adrAction->setEnabled(FALSE);
@@ -579,7 +590,23 @@ void Ihu::applySettings()
 	
 	agcRefresh(config.readBoolEntry("/ihu/sound/agc"));
 	
-	logger->enable(config.readEntry("/ihu/security/logfile"));
+	QString nname;
+	
+	try
+	{
+		nname = QString("/ihu/security/logfile");
+		logger->enable(config.readEntry(nname));
+		nname = QString("/ihu/general/dumpout");
+		transmitter->dump(config.readEntry(nname));
+		nname = QString("/ihu/general/dumpin");
+		receiver->dump(config.readEntry(nname));
+	}
+	catch (Error e)
+	{
+		showMessageCritical(e.getText());
+		config.writeEntry(nname, "");
+	}
+
 }
 
 void Ihu::txLedEnable(bool on)
@@ -617,6 +644,7 @@ void Ihu::answer()
 		hostEdit->setEnabled(FALSE);
 		hostname->setEnabled(FALSE);
 		filePlayFileAction->setEnabled(FALSE);
+		fileConvertFileAction->setEnabled(FALSE);
 		ringButton->setEnabled(TRUE);
 		waitButton->setEnabled(FALSE);
 		received = false;
@@ -644,6 +672,7 @@ void Ihu::call(QString host)
 		hostEdit->setEnabled(FALSE);
 		hostname->setEnabled(FALSE);
 		filePlayFileAction->setEnabled(FALSE);
+		fileConvertFileAction->setEnabled(FALSE);
 		ringButton->setEnabled(TRUE);
 		waitButton->setEnabled(FALSE);
 		tx->setEnabled(TRUE);
@@ -654,7 +683,15 @@ void Ihu::call(QString host)
 			listening = false;
 			receiver->end();
 		}
-		int sd =  transmitter->call(host, config.readNumEntry("/ihu/net/outport"), config.readNumEntry("/ihu/net/protocol"));
+		int callPort = config.readNumEntry("/ihu/net/outport");
+		QString callHost = host;
+		int tmpInd = host.findRev(':');
+		if (tmpInd > 0)
+		{
+			callHost = host.left(tmpInd);
+			callPort = host.right(host.length() - tmpInd - 1).toInt();
+		}
+		int sd = transmitter->call(callHost, callPort, config.readNumEntry("/ihu/net/protocol"));
 		receiver->start(sd, config.readNumEntry("/ihu/net/protocol"));
 		logViewer->addLog(logger->logOutgoingCall(host, transmitter->getIp()));
 		ringButton->toggle();
@@ -674,6 +711,7 @@ void Ihu::waitCalls(bool on)
 	if (on)
 	{
 		waitButton->setIconSet( QIconSet( QPixmap::fromMimeSource( "receive.png" ) ) );
+		waitButton->setText( tr( "&Waiting for calls" ) );
 		receiver->resetCalls();
 		listen();
 	}
@@ -681,8 +719,10 @@ void Ihu::waitCalls(bool on)
 	{
 		restartTimer->stop();
 		filePlayFileAction->setEnabled(TRUE);
+		fileConvertFileAction->setEnabled(TRUE);
 		rxLedEnable(FALSE);
 		waitButton->setIconSet( QIconSet( QPixmap::fromMimeSource( "receive_no.png" ) ) );
+		waitButton->setText( tr( "&Wait for calls" ) );
 		if (trayIcon)
 		{
 			changeTrayIcon(IHU_ICON_NORMAL);
@@ -699,6 +739,7 @@ void Ihu::listen()
 {
 	try {
 		filePlayFileAction->setEnabled(FALSE);
+		fileConvertFileAction->setEnabled(FALSE);
 		if (trayIcon)
 		{
 			changeTrayIcon(IHU_ICON_WAIT);
@@ -802,7 +843,6 @@ void Ihu::stopAll()
 		stopButton->setText("&Hang up");
 		hostEdit->setEnabled(TRUE);
 		hostname->setEnabled(TRUE);
-		filePlayFileAction->setEnabled(TRUE);
 		ringButton->setEnabled(FALSE);
 		waitButton->setEnabled(TRUE);
 		tx->setEnabled(FALSE);
@@ -814,16 +854,18 @@ void Ihu::stopAll()
 			ringButton->toggle();
 		timer->stop();
 		fileName = QString::null;
+		receiver->end();
+		transmitter->end();
 		if (fromFile)
 		{
 			fromFile = false;
 			adrAction->setEnabled(TRUE);
 			adrRefresh(config.readBoolEntry("/ihu/sound/adr"));
 			thSlider->setValue(config.readNumEntry("/ihu/sound/threshold"));
+			threshold->setText( QString( "TX threshold: %1 \%" ).arg( thSlider->value() ) );
 		}
+		ihu2spx = false;
 		received = false;
-		receiver->end();
-		transmitter->end();
 		sliderFree = true;
 		rxLedEnable(FALSE);
 		txLedEnable(FALSE);
@@ -832,6 +874,11 @@ void Ihu::stopAll()
 			QToolTip::add( trayIcon, "IHU" );
 		if (waitButton->isOn())
 			restartTimer->start(RESTART_TIME, true);
+		else
+		{
+			filePlayFileAction->setEnabled(TRUE);
+			fileConvertFileAction->setEnabled(TRUE);
+		}
 	}
 	catch (Error e)
 	{
@@ -845,6 +892,13 @@ void Ihu::play()
 	playFile(name);
 }
 
+void Ihu::convert()
+{
+        QString name=QFileDialog::getOpenFileName("","*"IHU_EXT,this,0,"Open IHU file to convert...");
+	ihu2spx = true;
+	playFile(name);
+}
+
 void Ihu::playFile(QString name)
 {
 	if (!name.isEmpty())
@@ -855,15 +909,23 @@ void Ihu::playFile(QString name)
 			stopButton->setEnabled(TRUE);
 			waitButton->setEnabled(FALSE);
 			filePlayFileAction->setEnabled(FALSE);
+			fileConvertFileAction->setEnabled(FALSE);
 			adrAction->setEnabled(FALSE);
 			hostEdit->setEnabled(FALSE);
 			hostname->setEnabled(FALSE);
 			callButton->setText( tr("&Pause") );
 			stopButton->setText( tr("S&top") );
-			message("Playing " + fileName + "...") ;
 			fileName = name;
+			if (ihu2spx)
+				message("Converting " + fileName + "...") ;
+			else
+				message("Playing " + fileName + "...") ;
+			threshold->setText(tr("File progress: 0 \%"));
 			fromFile = true;
-			receiver->playFile(fileName);
+			if (ihu2spx)
+				receiver->convertFile(fileName);
+			else
+				receiver->playFile(fileName);
 			timer->start(STAT_TIME, false);
 		}
 		catch (Error e)
@@ -1216,7 +1278,10 @@ void Ihu::statistics()
 {
 	if (fromFile)
 	{
-		message(QString("Playing %1 (%2)").arg(fileName).arg(receiver->getCallerName()));
+		if (ihu2spx)
+			message("Converting " + fileName + "...") ;
+		else
+			message(QString("Playing %1 (%2)").arg(fileName).arg(receiver->getCallerName()));
 	}
 	else
 	{
@@ -1254,17 +1319,6 @@ void Ihu::helpContents()
 	"http://ihu.sourceforge.net/doc/manual.html");
 }
 
-void Ihu::helpAbout()
-{
-	QMessageBox::about( this, "About IHU", "I  Hear  U  v. "VERSION" (2005/Dec/07) written by Matteo Trotta\n\n"
-	"Copyright (C) 2003-2005 Matteo Trotta. All rights reserved.\n"
-	"Distributed under the terms of GNU General Public License.\n\n"
-	"Using Speex v. 1.1.11 Copyright (C) Jean-Marc Valin.\n"
-	"Using SoundTouch v.1.3.0 Copyright (C) Olli Parviainen.\n\n"
-	"Visit home page at http://ihu.sourceforge.net\n"
-	);
-}
-
 void Ihu::disableIn()
 {
 	muteMicButton->toggle();
@@ -1355,3 +1409,14 @@ void Ihu::receivedNewKey(QString text)
 	}
 	tocrypt = true;
 }
+
+void Ihu::helpAbout()
+{
+	QMessageBox::about( this, "About IHU", "I  Hear  U  v. "VERSION" ("VDATE") written by Matteo Trotta\n\n"
+	"Copyright (C) 2003-2006 Matteo Trotta. All rights reserved.\n"
+	"Distributed under the terms of GNU General Public License.\n\n"
+	"Using Speex - Copyright (C) Jean-Marc Valin\n"
+	"Using SoundTouch - Copyright (C) Olli Parviainen\n\n"
+	"Visit home page at http://ihu.sourceforge.net\n"
+	);
+}
