@@ -1,7 +1,7 @@
 /*
  *  IHU -- I Hear U, easy VoIP application using Speex and Qt
  *
- *  Copyright (C) 2003-2005 M. Trotta - <mrotta@users.sourceforge.net>
+ *  Copyright (C) 2003-2006 Matteo Trotta - <mrotta@users.sourceforge.net>
  *
  *  http://ihu.sourceforge.net
  *
@@ -39,11 +39,12 @@
 #include <qfiledialog.h>
 #include <qradiobutton.h>
 #include <qbuttongroup.h>
+#include <qslider.h>
 
 #include <alsa/asoundlib.h>
 
 #include "Settings.hpp"
-#include "Error.hpp"
+#include "Error.h"
 
 #define NAME_CUT 15
 
@@ -167,12 +168,14 @@ Settings::Settings( QWidget* parent, const char* name, bool modal, WFlags fl )
 	inportBox->setMinValue( 1 );
 	inportBox->setValue( config.readNumEntry("/ihu/net/inport") );
 	
+	nlay1->addStretch(1);
 	nlay1->addWidget(inprotocolLabel);
 	nlay1->addWidget(udpBox);
 	nlay1->addWidget(tcpBox);
-	nlay1->addStretch();
+	nlay1->addStretch(2);
 	nlay1->addWidget(inportLabel);
 	nlay1->addWidget(inportBox);
+	nlay1->addStretch(1);
 	
 	QBoxLayout *nouttopLayout = new QVBoxLayout( netOutGroup, 20);
 	QBoxLayout *nlay2 = new QHBoxLayout( nouttopLayout, 10 );
@@ -194,12 +197,14 @@ Settings::Settings( QWidget* parent, const char* name, bool modal, WFlags fl )
 	outportBox->setMinValue( 1 );
 	outportBox->setValue( config.readNumEntry("/ihu/net/outport") );
 	
+	nlay2->addStretch(1);
 	nlay2->addWidget(protocolLabel);
 	nlay2->addWidget(udpRadioButton);
 	nlay2->addWidget(tcpRadioButton);
-	nlay2->addStretch();
+	nlay2->addStretch(2);
 	nlay2->addWidget(outportLabel);
 	nlay2->addWidget(outportBox);
+	nlay2->addStretch(1);
 	
 	QBoxLayout *sLayout = new QVBoxLayout( soundWidget, 10 );
 	
@@ -226,6 +231,21 @@ Settings::Settings( QWidget* parent, const char* name, bool modal, WFlags fl )
 #endif
 	dspBox->setCurrentItem( config.readNumEntry("/ihu/sound/inputdriver") + config.readNumEntry("/ihu/sound/outputdriver"));
 	
+	ringVolumeLabel = new QLabel( soundGroup, "ringVolumeLabel" );
+	
+	ringVolumeBox = new QComboBox( soundGroup, "ringVolumeBox" );
+	ringVolumeBox->insertItem( tr( "Off" ), 0);
+	ringVolumeBox->insertItem( tr( "High" ), 1);
+	ringVolumeBox->insertItem( tr( "Medium" ), 2);
+	ringVolumeBox->insertItem( tr( "Low" ), 3);
+	ringVolumeBox->setCurrentItem( config.readNumEntry("/ihu/sound/ringvolume") );
+	
+	slay1->addWidget(dspLabel);
+	slay1->addWidget(dspBox, 1);
+	slay1->addStretch(1);
+	slay1->addWidget(ringVolumeLabel);
+	slay1->addWidget(ringVolumeBox);
+	
 	interfInLabel = new QLabel( soundGroup, "interfInLabel" );
 	
 	interfInBox = new QComboBox( TRUE, soundGroup, "interfaceBox" );
@@ -264,8 +284,11 @@ Settings::Settings( QWidget* parent, const char* name, bool modal, WFlags fl )
 	interfInBox->setEditText(config.readEntry("/ihu/sound/inputinterface"));
 	interfOutBox->setEditText(config.readEntry("/ihu/sound/outputinterface"));
 	
-	slay1->addWidget(dspLabel);
-	slay1->addWidget(dspBox, 1);
+	slay2->addWidget(interfInLabel);
+	slay2->addWidget(interfInBox);
+	slay2->addStretch();
+	slay2->addWidget(interfOutLabel);
+	slay2->addWidget(interfOutBox);
 	
 	modeLabel = new QLabel( soundGroup, "modeLabel" );
 	
@@ -275,12 +298,6 @@ Settings::Settings( QWidget* parent, const char* name, bool modal, WFlags fl )
 	modeBox->insertItem( tr( "ultra-wide (32000 Hz, 16 bit, Mono)" ), IHU_ULTRAWIDE);
 	modeBox->setCurrentItem( config.readNumEntry("/ihu/speex/mode") );
 	
-	slay2->addWidget(interfInLabel);
-	slay2->addWidget(interfInBox);
-	slay2->addStretch();
-	slay2->addWidget(interfOutLabel);
-	slay2->addWidget(interfOutBox);
-	
 	slay3->addWidget(modeLabel);
 	slay3->addWidget(modeBox, 1);
 	
@@ -291,22 +308,18 @@ Settings::Settings( QWidget* parent, const char* name, bool modal, WFlags fl )
 	stoptxBox->setMinValue( 0 );
 	stoptxBox->setValue( config.readNumEntry("/ihu/sound/txstop") );
 	
-	ringVolumeLabel = new QLabel( soundGroup, "ringVolumeLabel" );
+	prepacketsLabel = new QLabel( soundGroup, "prepacketsLabel" );
 	
-	ringVolumeBox = new QComboBox( soundGroup, "ringVolumeBox" );
-	ringVolumeBox->insertItem( tr( "Off" ), 0);
-	ringVolumeBox->insertItem( tr( "High" ), 1);
-	ringVolumeBox->insertItem( tr( "Medium" ), 2);
-	ringVolumeBox->insertItem( tr( "Low" ), 3);
-	ringVolumeBox->setCurrentItem( config.readNumEntry("/ihu/sound/ringvolume") );
+	prepacketsBox = new QSpinBox( soundGroup, "prepacketsBox" );
+	prepacketsBox->setMaxValue( 20 );
+	prepacketsBox->setMinValue( 0 );
+	prepacketsBox->setValue( config.readNumEntry("/ihu/sound/prepackets") );
 	
-	slay4->addStretch(1);
 	slay4->addWidget(stoptxLabel);
 	slay4->addWidget(stoptxBox);
 	slay4->addStretch(1);
-	slay4->addWidget(ringVolumeLabel);
-	slay4->addWidget(ringVolumeBox);
-	slay4->addStretch(1);
+	slay4->addWidget(prepacketsLabel);
+	slay4->addWidget(prepacketsBox);
 	
 	QBoxLayout *eLayout = new QVBoxLayout( encoderWidget, 10 );
 	
@@ -440,10 +453,11 @@ Settings::Settings( QWidget* parent, const char* name, bool modal, WFlags fl )
 	
 	agcSpeedLabel = new QLabel( agcGroup, "agcSpeedLabel" );
 	
-	agcstepBox = new QSpinBox( agcGroup, "agcstepBox" );
-	agcstepBox->setMaxValue( 1000 );
-	agcstepBox->setMinValue( 1 );
-	agcstepBox->setValue( config.readNumEntry("/ihu/sound/agcstep") );
+	agcstep = new QSlider( agcGroup, "agcstep" );
+	agcstep->setOrientation( QSlider::Horizontal );
+	agcstep->setMaxValue( 500 );
+	agcstep->setMinValue( 1 );
+	agcstep->setValue( config.readNumEntry("/ihu/sound/agcstep") );
 	
 	agcminLabel = new QLabel( agcGroup, "agcminLabel" );
 	
@@ -454,14 +468,14 @@ Settings::Settings( QWidget* parent, const char* name, bool modal, WFlags fl )
 	
 	agcmaxLabel = new QLabel( agcGroup, "agcmaxLabel" );
 	
-	agcmaxBox = new QSpinBox( agcGroup, "agcstepBox" );
+	agcmaxBox = new QSpinBox( agcGroup, "agcmaxBox" );
 	agcmaxBox->setMaxValue( 50 );
 	agcmaxBox->setMinValue( 1 );
 	agcmaxBox->setValue( config.readNumEntry("/ihu/sound/agcmax") );
 	
 	olay3->addStretch(1);
 	olay3->addWidget(agcSpeedLabel, 2);
-	olay3->addWidget(agcstepBox, 2);
+	olay3->addWidget(agcstep, 2);
 	olay3->addStretch(1);
 	
 	olay4->addWidget(agcminLabel);
@@ -602,16 +616,17 @@ void Settings::languageChange()
 	udpBox->setText( tr( "UDP" ) );
 	tcpBox->setText( tr( "TCP" ) );
 	inportLabel->setText( tr( "Port:" ) );
-	outportLabel->setText( tr( "Port:" ) );
-	dspLabel->setText( tr( "Sound driver" ) );
+	outportLabel->setText( tr( "Default port:" ) );
+	dspLabel->setText( tr( "Driver" ) );
 	interfInLabel->setText( tr( "Input interface" ) );
 	interfOutLabel->setText( tr( "Output interface" ) );
 	stoptxLabel->setText( tr( "Stop TX after (silence secs)" ) );
-	ringVolumeLabel->setText( tr( "Ring Volume" ) );
+	ringVolumeLabel->setText( tr( "Ring volume" ) );
+	prepacketsLabel->setText( tr( "Packets prebuffer" ) );
 	adrmindelayLabel->setText( tr( "Minimum delay (ms)" ) );
 	adrmaxdelayLabel->setText( tr( "Maximum delay (ms)" ) );
 	adrstretchLabel->setText( tr( "Time change percentage (0-50 \%)") );
-	agcSpeedLabel->setText( tr( "Volume change speed (1-100)" ) );
+	agcSpeedLabel->setText( tr( "Volume change speed" ) );
 	agcminLabel->setText( tr( "Minimum gain factor" ) );
 	agcmaxLabel->setText( tr( "Maximum gain factor" ) );
 	modeLabel->setText( tr( "Input format" ) );
@@ -655,10 +670,11 @@ void Settings::languageChange()
 	QWhatsThis::add(modeBox, tr("The input format determines the audio quality and the network usage for your voice. To improve the sound quality of your voice, choose a higher sample rate."));
 	QWhatsThis::add(stoptxBox, tr("When you are using a threshold greater than zero, it's useful to continue the transmission for some seconds, to preserve the stream against small speech pauses."));
 	QWhatsThis::add(ringVolumeBox, tr("Here you can adjust the volume of ring tone for incoming calls."));
+	QWhatsThis::add(prepacketsBox, tr("Number of packets to prebuffer before starting to play. A high number of packets ensure audio continuity, but it could increase the audio delay."));
 	QWhatsThis::add(adrmindelayBox, tr("This is the minimum audio delay on the output sound interface. When ADR is activated, if the delay is smaller than maximum, IHU will try to increase the delay to this value in order to avoid sound crackle."));
 	QWhatsThis::add(adrmaxdelayBox, tr("This is the maximum audio delay on the output sound interface. When ADR is activated, if the delay is greater than minimum, IHU will try to reduce the delay to this value."));
 	QWhatsThis::add(adrstretchBox, tr("This is the time change percentage for ADR. If the current playback delay is smaller/greater than reference values, than IHU will adjust the current audio stream. A higher time stretch means faster adjustment."));
-	QWhatsThis::add(agcstepBox, tr("This value will influence the rapidity of AGC volume adjustment (you can change the reference volume from the main window)."));
+	QWhatsThis::add(agcstep, tr("This value will influence the rapidity of AGC volume adjustment (you can change the reference volume from the main window)."));
 	QWhatsThis::add(agcminBox, tr("The minimum amplitude value. If you think that the volume is getting too low, you can adjust this value."));
 	QWhatsThis::add(agcmaxBox, tr("The maximum amplitude value. If you think that the volume is getting too high, you can adjust this value to limit the amplitude. This is useful to avoid excessive silence amplification."));
 	QWhatsThis::add(bitrateBox, tr("Choose the encoding bitrate type for your voice beetween: Constant (CBR), Variable (VBR), Average (ABR)."));
@@ -733,7 +749,8 @@ void Settings::saveSettings()
 		config.writeEntry("/ihu/sound/outputinterface", interfOutBox->currentText());
 		config.writeEntry("/ihu/sound/txstop", stoptxBox->value());
 		config.writeEntry("/ihu/sound/ringvolume", ringVolumeBox->currentItem());
-		config.writeEntry("/ihu/sound/agcstep", agcstepBox->value());
+		config.writeEntry("/ihu/sound/prepackets", prepacketsBox->value());
+		config.writeEntry("/ihu/sound/agcstep", agcstep->value());
 		config.writeEntry("/ihu/sound/agcmin", agcminBox->value());
 		config.writeEntry("/ihu/sound/agcmax", agcmaxBox->value());
 		config.writeEntry("/ihu/sound/adrmindelay", adrmindelayBox->value());
@@ -764,38 +781,63 @@ void Settings::saveSettings()
 
 void Settings::defaults()
 {
-	inportBox->setValue(IHU_DEFAULT_INPORT);
-	outportBox->setValue(IHU_DEFAULT_OUTPORT);
-	udpBox->setChecked(IHU_DEFAULT_UDP);
-	tcpBox->setChecked(IHU_DEFAULT_TCP);
-	answerBox->setChecked(IHU_DEFAULT_ANSWER);
-	trayBox->setChecked(IHU_DEFAULT_TRAY);
-	waitBox->setChecked(IHU_DEFAULT_WAIT);
-	hideBox->setChecked(IHU_DEFAULT_HIDE);
-	modeBox->setCurrentItem(IHU_DEFAULT_MODE);
-	bitrateBox->setCurrentItem(IHU_DEFAULT_BITRATEMODE);
-	stoptxBox->setValue(IHU_DEFAULT_TXSTOP);
-	ringVolumeBox->setCurrentItem(IHU_DEFAULT_RINGVOLUME);
-	complexityBox->setValue(IHU_DEFAULT_COMPLEXITY);
-	cbrqualityBox->setValue(IHU_DEFAULT_QUALITY);
-	vbrqualityBox->setValue(IHU_DEFAULT_VBRQUALITY);
-	abrBox->setValue(IHU_DEFAULT_ABR);
-	vadBox->setChecked(IHU_DEFAULT_VAD);
-	dtxBox->setChecked(IHU_DEFAULT_DTX);
-	dspBox->setCurrentItem(IHU_DEFAULT_INDRIVER + IHU_DEFAULT_OUTDRIVER);
-	interfInBox->setCurrentText(IHU_DEFAULT_INTERFACE);
-	interfOutBox->setCurrentText(IHU_DEFAULT_INTERFACE);
-	agcstepBox->setValue(IHU_DEFAULT_AGCSTEP);
-	agcminBox->setValue(IHU_DEFAULT_AGCMIN);
-	agcmaxBox->setValue(IHU_DEFAULT_AGCMAX);
-	adrmindelayBox->setValue(IHU_DEFAULT_ADRMINDELAY);
-	adrmaxdelayBox->setValue(IHU_DEFAULT_ADRMAXDELAY);
-	adrstretchBox->setValue(IHU_DEFAULT_ADRSTRETCH);
-	bitsBox->setValue(IHU_DEFAULT_KEYLEN);
-	udpRadioButton->setChecked(TRUE);
-	randomRadioButton->setChecked(IHU_DEFAULT_RANDOM);
-	showkeyBox->setChecked(IHU_DEFAULT_SHOWKEY);
-	bitrateChanged();
+	if (currentPage() == generalWidget)
+	{
+		answerBox->setChecked(IHU_DEFAULT_ANSWER);
+		trayBox->setChecked(IHU_DEFAULT_TRAY);
+		waitBox->setChecked(IHU_DEFAULT_WAIT);
+		hideBox->setChecked(IHU_DEFAULT_HIDE);
+	}
+	else
+	if (currentPage() == netWidget)
+	{
+		inportBox->setValue(IHU_DEFAULT_INPORT);
+		outportBox->setValue(IHU_DEFAULT_OUTPORT);
+		udpBox->setChecked(IHU_DEFAULT_UDP);
+		tcpBox->setChecked(IHU_DEFAULT_TCP);
+		udpRadioButton->setChecked(TRUE);
+	}
+	else
+	if (currentPage() == soundWidget)
+	{
+		modeBox->setCurrentItem(IHU_DEFAULT_MODE);
+		stoptxBox->setValue(IHU_DEFAULT_TXSTOP);
+		ringVolumeBox->setCurrentItem(IHU_DEFAULT_RINGVOLUME);
+		prepacketsBox->setValue(IHU_DEFAULT_PREPACKETS);
+		dspBox->setCurrentItem(IHU_DEFAULT_INDRIVER + IHU_DEFAULT_OUTDRIVER);
+		interfInBox->setCurrentText(IHU_DEFAULT_INTERFACE);
+		interfOutBox->setCurrentText(IHU_DEFAULT_INTERFACE);
+	}
+	else
+	if (currentPage() == encoderWidget)
+	{
+		bitrateBox->setCurrentItem(IHU_DEFAULT_BITRATEMODE);
+		complexityBox->setValue(IHU_DEFAULT_COMPLEXITY);
+		cbrqualityBox->setValue(IHU_DEFAULT_QUALITY);
+		vbrqualityBox->setValue(IHU_DEFAULT_VBRQUALITY);
+		abrBox->setValue(IHU_DEFAULT_ABR);
+		vadBox->setChecked(IHU_DEFAULT_VAD);
+		dtxBox->setChecked(IHU_DEFAULT_DTX);
+		bitrateChanged();
+	}
+	else
+	if (currentPage() == optionsWidget)
+	{
+		agcstep->setValue(IHU_DEFAULT_AGCSTEP);
+		agcminBox->setValue(IHU_DEFAULT_AGCMIN);
+		agcmaxBox->setValue(IHU_DEFAULT_AGCMAX);
+		adrmindelayBox->setValue(IHU_DEFAULT_ADRMINDELAY);
+		adrmaxdelayBox->setValue(IHU_DEFAULT_ADRMAXDELAY);
+		adrstretchBox->setValue(IHU_DEFAULT_ADRSTRETCH);
+	}
+	else
+	if (currentPage() == securityWidget)
+	{
+		bitsBox->setValue(IHU_DEFAULT_KEYLEN);
+		randomRadioButton->setChecked(IHU_DEFAULT_RANDOM);
+		showkeyBox->setChecked(IHU_DEFAULT_SHOWKEY);
+	}
+
 }
 
 void Settings::logEnable(bool on)
