@@ -1,7 +1,7 @@
 /*
  *  IHU -- I Hear U, easy VoIP application using Speex and Qt
  *
- *  Copyright (C) 2003-2005 M. Trotta - <mrotta@users.sourceforge.net>
+ *  Copyright (C) 2003-2006 Matteo Trotta - <mrotta@users.sourceforge.net>
  *
  *  http://ihu.sourceforge.net
  *
@@ -23,7 +23,7 @@
 #include <qstring.h>
 #include <qsocketdevice.h>
 #include "TcpServer.hpp"
-#include "Error.hpp"
+#include "Error.h"
 
 TcpServer::TcpServer( QObject* parent=0, int port = 0) :
         QServerSocket(port,1,parent)
